---
Title: Utiliser un papier à en-tête avec LaTeX
Date: 2019-04-22 20:00
Modified: 2019-04-24 10:25
Author: Fabrice
Category: astuces
Lang: fr
Tags: LaTeX
Slug: latex-letterhead
Header_Cover: ../images/covers/palace.jpg
Summary: Une astuce pour rapidement pouvoir utiliser n’importe quel papier à en-tête avec LaTeX à l’aide du package wallpaper.
---

Il m’arrive parfois de devoir écrire des documents officiels, en particuliers pour les démarches administratives.
Cependant, les modèles de lettres sont souvent disponibles dans des [formats propriétaires](https://en.wikipedia.org/wiki/Office_Open_XML) avec lesquels j’essaye de limiter les interactions au possible.
En particulier, je suis plus à l’aise pour écrire mes documents à l’aide de LaTeX plutôt que d’utiliser [libreoffice](https://libreoffice.org/) par exemple.

Et donc, grâce à [Nicolas Trotignon](https://perso.ens-lyon.fr/nicolas.trotignon/) qui a trouvé cette petite astuce, je vous présente la méthode.  
Avant de commencer, il faudra trouver une version pdf des modèles de letters. Pour ce faire, j’utilise (honteusement) la suite [office 365](https://en.wikipedia.org/wiki/Office_365) dans sa version navigateur pour exporter le pdf des documents désirés.

Ceci fait, tout repose maintenant sur le paquet [wallpaper](https://www.ctan.org/pkg/wallpaper) pour inclure le modèle de lettre comme font de page, et ensuite jouer avec les [marges](https://ctan.org/pkg/geometry) pour ajuster le tout.

Ainsi voici un exemple minimal avec la [sortie correspondante]({static}/examples/background-latex.pdf).  
Bien entendu, remplacez `fond.pdf` par votre fond de page.
Cela peut aussi être adapté à d’autres classes, comme [`lettre.cls`](https://ctan.org/pkg/lettre).

```tex
\documentclass[a4paper]{article}
% Mise en page et encodage
\usepackage[utf8]{inputenc}
\usepackage[UKenglish]{babel}
\usepackage[T1]{fontenc}
\usepackage{libertine}
% La grosse astuce
\usepackage{wallpaper}
\CenterWallPaper{1}{background.pdf}
% Marges
\usepackage[inner=4.5cm,top=6cm]{geometry}
\begin{document}
% blabla
Hello, World!
% …
\end{document}
```
